Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/usr.bin/make make(1): rename Var_ExportVars to Var_ReexportVars



details:   https://anonhg.NetBSD.org/src/rev/90051fc9e367
branches:  trunk
changeset: 947174:90051fc9e367
user:      rillig <rillig%NetBSD.org@localhost>
date:      Sat Dec 12 18:53:53 2020 +0000

description:
make(1): rename Var_ExportVars to Var_ReexportVars

diffstat:

 usr.bin/make/compat.c  |  6 +++---
 usr.bin/make/job.c     |  6 +++---
 usr.bin/make/main.c    |  6 +++---
 usr.bin/make/nonints.h |  4 ++--
 usr.bin/make/var.c     |  9 +++++----
 5 files changed, 16 insertions(+), 15 deletions(-)

diffs (136 lines):

diff -r 8e3418539566 -r 90051fc9e367 usr.bin/make/compat.c
--- a/usr.bin/make/compat.c     Sat Dec 12 18:45:11 2020 +0000
+++ b/usr.bin/make/compat.c     Sat Dec 12 18:53:53 2020 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: compat.c,v 1.207 2020/12/12 00:33:25 rillig Exp $      */
+/*     $NetBSD: compat.c,v 1.208 2020/12/12 18:53:53 rillig Exp $      */
 
 /*
  * Copyright (c) 1988, 1989, 1990 The Regents of the University of California.
@@ -96,7 +96,7 @@
 #include "pathnames.h"
 
 /*     "@(#)compat.c   8.2 (Berkeley) 3/19/94" */
-MAKE_RCSID("$NetBSD: compat.c,v 1.207 2020/12/12 00:33:25 rillig Exp $");
+MAKE_RCSID("$NetBSD: compat.c,v 1.208 2020/12/12 18:53:53 rillig Exp $");
 
 static GNode *curTarg = NULL;
 static pid_t compatChild;
@@ -348,7 +348,7 @@
                Fatal("Could not fork");
        }
        if (cpid == 0) {
-               Var_ExportVars();
+               Var_ReexportVars();
 #ifdef USE_META
                if (useMeta) {
                        meta_compat_child();
diff -r 8e3418539566 -r 90051fc9e367 usr.bin/make/job.c
--- a/usr.bin/make/job.c        Sat Dec 12 18:45:11 2020 +0000
+++ b/usr.bin/make/job.c        Sat Dec 12 18:53:53 2020 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: job.c,v 1.384 2020/12/12 13:13:34 rillig Exp $ */
+/*     $NetBSD: job.c,v 1.385 2020/12/12 18:53:53 rillig Exp $ */
 
 /*
  * Copyright (c) 1988, 1989, 1990 The Regents of the University of California.
@@ -143,7 +143,7 @@
 #include "trace.h"
 
 /*     "@(#)job.c      8.2 (Berkeley) 3/19/94" */
-MAKE_RCSID("$NetBSD: job.c,v 1.384 2020/12/12 13:13:34 rillig Exp $");
+MAKE_RCSID("$NetBSD: job.c,v 1.385 2020/12/12 18:53:53 rillig Exp $");
 
 /*
  * A shell defines how the commands are run.  All commands for a target are
@@ -1459,7 +1459,7 @@
 #  endif
 #endif
 
-               Var_ExportVars();
+               Var_ReexportVars();
 
                (void)execv(shellPath, argv);
                execDie("exec", shellPath);
diff -r 8e3418539566 -r 90051fc9e367 usr.bin/make/main.c
--- a/usr.bin/make/main.c       Sat Dec 12 18:45:11 2020 +0000
+++ b/usr.bin/make/main.c       Sat Dec 12 18:53:53 2020 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: main.c,v 1.494 2020/12/11 23:00:59 rillig Exp $        */
+/*     $NetBSD: main.c,v 1.495 2020/12/12 18:53:53 rillig Exp $        */
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -109,7 +109,7 @@
 #include "trace.h"
 
 /*     "@(#)main.c     8.3 (Berkeley) 3/19/94" */
-MAKE_RCSID("$NetBSD: main.c,v 1.494 2020/12/11 23:00:59 rillig Exp $");
+MAKE_RCSID("$NetBSD: main.c,v 1.495 2020/12/12 18:53:53 rillig Exp $");
 #if defined(MAKE_NATIVE) && !defined(lint)
 __COPYRIGHT("@(#) Copyright (c) 1988, 1989, 1990, 1993 "
            "The Regents of the University of California.  "
@@ -1799,7 +1799,7 @@
                (void)dup2(pipefds[1], 1);
                (void)close(pipefds[1]);
 
-               Var_ExportVars();
+               Var_ReexportVars();
 
                (void)execv(shellPath, UNCONST(args));
                _exit(1);
diff -r 8e3418539566 -r 90051fc9e367 usr.bin/make/nonints.h
--- a/usr.bin/make/nonints.h    Sat Dec 12 18:45:11 2020 +0000
+++ b/usr.bin/make/nonints.h    Sat Dec 12 18:53:53 2020 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: nonints.h,v 1.166 2020/12/12 00:05:05 rillig Exp $     */
+/*     $NetBSD: nonints.h,v 1.167 2020/12/12 18:53:53 rillig Exp $     */
 
 /*-
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -323,7 +323,7 @@
 VarParseResult Var_Subst(const char *, GNode *, VarEvalFlags, char **);
 void Var_Stats(void);
 void Var_Dump(GNode *);
-void Var_ExportVars(void);
+void Var_ReexportVars(void);
 void Var_Export(const char *, Boolean);
 void Var_UnExport(const char *);
 
diff -r 8e3418539566 -r 90051fc9e367 usr.bin/make/var.c
--- a/usr.bin/make/var.c        Sat Dec 12 18:45:11 2020 +0000
+++ b/usr.bin/make/var.c        Sat Dec 12 18:53:53 2020 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: var.c,v 1.724 2020/12/12 18:11:42 rillig Exp $ */
+/*     $NetBSD: var.c,v 1.725 2020/12/12 18:53:53 rillig Exp $ */
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -98,7 +98,8 @@
  *
  *     Var_Delete      Delete a variable.
  *
  *     Var_ExportVars  Export some or even all variables to the environment
  *                     of this process and its child processes.
  *
  *     Var_Export      Export the variable to the environment of this process
@@ -130,7 +131,7 @@
 #include "metachar.h"
 
 /*     "@(#)var.c      8.3 (Berkeley) 3/19/94" */
-MAKE_RCSID("$NetBSD: var.c,v 1.724 2020/12/12 18:11:42 rillig Exp $");
+MAKE_RCSID("$NetBSD: var.c,v 1.725 2020/12/12 18:53:53 rillig Exp $");
 
 /* A string that may need to be freed after use. */
 typedef struct FStr {
@@ -627,7 +628,7 @@
  * This gets called from our child processes.
  */
 void
-Var_ExportVars(void)
+Var_ReexportVars(void)
 {
        char *val;
 
@@ -98,7 +98,8 @@
  *     Var_Delete      Delete a variable.
  *
- *     Var_ExportVars  Export some or even all variables to the environment
+ *     Var_ReexportVars
+ *                     Export some or even all variables to the environment
  *                     of this process and its child processes.
  *



Home | Main Index | Thread Index | Old Index